@@ -14,7 +14,7 @@ from theme_settings import *
 
 
 from db_settings import DATABASES
-DATABASES['default']['DBNAME'] = 'backstage_%s_%s' % (VENUE_NAME, ACT_NAME)
+DATABASES['default']['NAME'] = 'backstage_%s_%s' % (VENUE_NAME, ACT_NAME)
 
 from act_settings import *
 
@@ -24,7 +24,7 @@ TEMPLATE_DIRS.insert(0, ACT_NAME + '/templates')
 
 ROOT_URLCONF = '%s.urls' % (ACT_NAME)
 
-STATIC_ROOT = os.path.join(ACT_HOME,'static/')
+STATIC_ROOT = os.path.join(ACT_HOME,'cstatic/')
 STATIC_URL = '/static/'
 
 INSTALLED_APPS += ACT_APPS
